## 3.3.0a0 (2024-09-16)

### Features

- Add monorepo support ([369e2d0](https://github.com/kpn/cz-kpn/commit/369e2d004cb07a0aec0aa17de33086cf53e2b002))

## 3.2.10 (2024-09-12)

### Fixes

- Test script ([200015a](https://github.com/kpn/cz-kpn/commit/200015af6145b42a5188ebef8b5f95a4fbaaca59))
- Ignore type hints ([7c603e5](https://github.com/kpn/cz-kpn/commit/7c603e536b9245d196f5d5f00f64ece613c0cc0e))

### Improvements

- Bump deps ([19d2503](https://github.com/kpn/cz-kpn/commit/19d250351fdfc2a8f73c38b51ecee98f233aecc1))

## 3.2.9 (2024-04-25)

### Fixes

- Set safe dir in docker image ([4c8f508](https://github.com/kpn/cz-kpn/commit/4c8f508b496c9f6e4371dfd1a9ce986a510aa05b))

### Improvements

- Update README ([3c077b5](https://github.com/kpn/cz-kpn/commit/3c077b54739507eb7c07ffdc3f7fcaeeb81da5a8))

## 3.2.8 (2024-04-25)

### Improvements

- Format readme ([451178c](https://github.com/kpn/cz-kpn/commit/451178c30831769c348fe362e2d5a38e56394f9f))

## 3.2.7 (2024-04-25)

### Improvements

- Use ruff latest and mypy ([d89f25e](https://github.com/kpn/cz-kpn/commit/d89f25e7613cfd7c993fd5ef68da91187c9c4321))

## 3.2.6 (2024-04-25)

### Improvements

- Increase wait time to release to docker ([178af5e](https://github.com/kpn/cz-kpn/commit/178af5e32943be5d57e5a1f69d6fcc85de06b8a8))

## 3.2.5 (2024-04-15)

### Fixes

- release pipeline ([1ab09a8](https://github.com/kpn/cz-kpn/commit/1ab09a840ba1e83ed57f524b5dba7fd385940ab0))

## 3.2.4 (2024-01-03)

### Improvements

- Bump docker github action ([4474f52](https://github.com/kpn/cz-kpn/commit/4474f52cf3334aaa5713651b3642d5ff1cf75256))

## 3.2.3 (2023-09-08)

### Improvements

- **ci**: Add sleep to let pypi publish py package ([625c993](https://github.com/kpn/cz-kpn/commit/625c9931d81325475ce227695bc854024da5471e))

## 3.2.2 (2023-09-08)

### Fixes

- Get current version in action ([233eaef](https://github.com/kpn/cz-kpn/commit/233eaef820a0ab941c73f6d2ce7385f0353c22ed))

## 3.2.1 (2023-09-08)

### Fixes

- Update dependencies ([d29c7d0](https://github.com/kpn/cz-kpn/commit/d29c7d0482e5c80ef0defcbfc4cc51f5ff18ca74))
- Add cz-kpn to github action ([54b9239](https://github.com/kpn/cz-kpn/commit/54b9239cd62538462adb9ce39b565bf7bab7fd36))

### Improvements

- Add repo badges ([568ad62](https://github.com/kpn/cz-kpn/commit/568ad62dc6fbe03ca415dcecb6c7d50458eab67d))
- Update pyproject.toml ([8ff761d](https://github.com/kpn/cz-kpn/commit/8ff761d9530654fbeb3112120ed09aed3a196a1b))
- Docker release ([4d8323c](https://github.com/kpn/cz-kpn/commit/4d8323c0d7ed922eb4b71dbf80065b361c7d2811))

## 3.2.0 (2023-09-08)

### Features

- Open source cz-kpn ([003ab88](https://github.com/kpn/cz-kpn/commit/003ab88d93f09a7b90b2bb144b8cd9d62419375f))
